@@ -61,7 +61,7 @@ class ObjectSegmentation(QWidget):
         training_widget.setLayout(QVBoxLayout())
 
         # Annotation
-        if self.classifier_class == ObjectSegmentation:
+        if self.classifier_class == ObjectSegmenter:
             suffix = " + object class"
         elif self.classifier_class == ProbabilityMapper:
             suffix = " + class for probability output"
@@ -80,7 +80,7 @@ class ObjectSegmentation(QWidget):
         num_object_annotation_spinner.setMaximumWidth(40)
         num_object_annotation_spinner.setMinimum(1)
         num_object_annotation_spinner.setValue(2)
-        if self.classifier_class == ObjectSegmentation:
+        if self.classifier_class == ObjectSegmenter:
             temp.layout().addWidget(num_object_annotation_spinner)
         elif self.classifier_class == ProbabilityMapper:
             temp.layout().addWidget(num_object_annotation_spinner)
@@ -193,7 +193,10 @@ class ObjectSegmentation(QWidget):
         @self.timer.timeout.connect
         def update_layer(*_):
             self.update_memory_consumption()
-            if not self.isVisible():
+            try:
+                if not self.isVisible():
+                    self.timer.stop()
+            except RuntimeError:
                 self.timer.stop()
 
         self.timer.start()
@@ -245,13 +248,13 @@ class ObjectSegmentation(QWidget):
 
     def _add_to_viewer(self, name, data):
         try:
-            self.viewer.layers[name].data = data
+            self.viewer.layers[name].data = data.astype(int)
             self.viewer.layers[name].visible = True
         except KeyError:
             if self.classifier_class == ProbabilityMapper:
                 self.viewer.add_image(data, name=name)
             else:
-                self.viewer.add_labels(data, name=name)
+                self.viewer.add_labels(data.astype(int), name=name)
 
     def predict(self, images, filename):
         print("predict")
@@ -277,14 +280,16 @@ class ObjectSegmentation(QWidget):
         self._add_to_viewer("Result of " + short_filename, result)
 
     def update_memory_consumption(self):
-        number_of_pixels = np.sum(np.prod(i.shape) for i in self.get_selected_images_data())
+        number_of_pixels = np.sum(tuple([np.prod(i.shape) for i in self.get_selected_images_data()]))
         number_of_features = len(self.feature_selector.getFeatures().split(" "))
         number_of_bytes_per_pixel = 4
 
         bytes = number_of_pixels * number_of_bytes_per_pixel * number_of_features
         text = "{bytes:.1f} MBytes".format(bytes=bytes / 1024 / 1024)
-        self.label_memory_consumption.setText("Estimated memory consumption (GPU): " + text)
-
+        try:
+            self.label_memory_consumption.setText("Estimated memory consumption (GPU): " + text)
+        except RuntimeError:
+            pass
 
     def update_label_list(self):
         selected_layer = self.get_selected_annotation()
